@@ -3,7 +3,7 @@ from typing import cast
 
 import pytest
 
-from hassil import Intents, recognize
+from hassil import Intents, recognize, recognize_all
 from hassil.expression import TextChunk
 from hassil.intents import TextSlotList
 
@@ -53,6 +53,15 @@ intents:
           domain:
             - "cover"
             - "light"
+  CloseCurtains:
+    data:
+      - sentences:
+          - "close [the] curtains [in <area>]"
+        slots:
+          domain: "cover"
+          device_class: "curtain"
+        requires_context:
+          area:
 expansion_rules:
   area: "[the] {area}"
   name: "[the] {name}"
@@ -89,6 +98,15 @@ def slot_lists():
                     "cover.garage_door",
                     {"domain": "cover"},
                 ),
+                (
+                    "blue curtains",
+                    "cover.blue_curtains",
+                    {
+                        "domain": "cover",
+                        "device_class": "curtain",
+                        "area": "living_room",
+                    },
+                ),
                 (
                     "roku",
                     "media_player.roku",
@@ -200,6 +218,29 @@ def test_play_no_cover(intents, slot_lists):
     assert result is None
 
 
+# pylint: disable=redefined-outer-name
+def test_requires_context_implicit(intents, slot_lists):
+    intent_context = {"area": "living room"}
+
+    result = recognize(
+        "close the curtains",
+        intents,
+        slot_lists=slot_lists,
+        intent_context=intent_context,
+    )
+    assert result is not None
+    assert result.intent.name == "CloseCurtains"
+
+    assert result.entities["domain"].value == "cover"
+    assert result.entities["device_class"].value == "curtain"
+
+
+# pylint: disable=redefined-outer-name
+def test_requires_context_none_provided(intents, slot_lists):
+    result = recognize("close the curtains", intents, slot_lists=slot_lists)
+    assert result is None
+
+
 def test_lists_no_template() -> None:
     """Ensure list values without template syntax are plain text."""
     yaml_text = """
@@ -321,7 +362,8 @@ def test_entity_text() -> None:
       TestIntent:
         data:
           - sentences:
-              - "run test {name} now"
+              - "run test {name} [now]"
+              - "{name} test"
     lists:
       name:
         values:
@@ -332,10 +374,11 @@ def test_entity_text() -> None:
     with io.StringIO(yaml_text) as test_file:
         intents = Intents.from_yaml(test_file)
 
-    result = recognize("run test alpha now", intents)
-    assert result is not None
-    assert result.entities["name"].value == "A"
-    assert result.entities["name"].text.strip() == "alpha"
+    for sentence in ("run test alpha now", "run test alpha", "alpha test"):
+        result = recognize(sentence, intents)
+        assert result is not None
+        assert result.entities["name"].value == "A"
+        assert result.entities["name"].text.strip() == "alpha"
 
 
 def test_number_text() -> None:
@@ -346,7 +389,8 @@ def test_number_text() -> None:
       TestIntent:
         data:
           - sentences:
-              - "set {percentage} now"
+              - "set {percentage} [now]"
+              - "{percentage} set"
     lists:
       percentage:
         range:
@@ -357,7 +401,34 @@ def test_number_text() -> None:
     with io.StringIO(yaml_text) as test_file:
         intents = Intents.from_yaml(test_file)
 
-    result = recognize("set 50% now", intents)
-    assert result is not None
-    assert result.entities["percentage"].value == 50
-    assert result.entities["percentage"].text.strip() == "50%"
+    for sentence in ("set 50% now", "set 50%", "50% set"):
+        result = recognize(sentence, intents)
+        assert result is not None
+        assert result.entities["percentage"].value == 50
+        assert result.entities["percentage"].text.strip() == "50%"
+
+
+def test_recognize_all() -> None:
+    """Test recognize_all method for returning all matches."""
+    yaml_text = """
+    language: "en"
+    intents:
+      TestIntent1:
+        data:
+          - sentences:
+              - "run test"
+      TestIntent2:
+        data:
+          - sentences:
+              - "run test"
+    """
+
+    with io.StringIO(yaml_text) as test_file:
+        intents = Intents.from_yaml(test_file)
+
+    results = list(recognize_all("run test", intents))
+    assert len(results) == 2
+    assert {result.intent.name for result in results} == {
+        "TestIntent1",
+        "TestIntent2",
+    }
